outbound

Function outbound 

pub fn outbound(
    config: OutboundConfig,
    outbound_rx: Receiver<InstructionType>,
    socket: Arc<Socket>,
) -> JoinHandle<()>
Starts the outbound worker thread that awaits tasks and sends probes.

Arguments

  • config - configuration for the outbound worker thread
  • outbound_rx - on this channel we receive future tasks that are part of the current measurement
  • socket - the sender object to send probe/discovery/trace packets

Returns

The join handle of the outbound thread, used to await its completion at the end of a measurement