OutboundConfig

Struct OutboundConfig 

pub struct OutboundConfig {
    pub worker_id: u16,
    pub abort_outbound: Arc<AtomicBool>,
    pub m_id: u32,
    pub p_type: ProtocolType,
    pub qname: Option<String>,
    pub info_url: Option<String>,
    pub probing_rate: u32,
    pub src: Address,
    pub sport: u16,
    pub dport: u16,
    pub origin_id: u32,
}
Configuration for the outbound/sending thread

Fields

worker_id: u16

The unique ID of this specific worker.

abort_outbound: Arc<AtomicBool>

Shared signal to forcefully shut down the worker (e.g., when the CLI disconnects).

m_id: u32

The 16-bit measurement ID

p_type: ProtocolType

Protocol type used

qname: Option<String>

Optional domain name to query in DNS measurement probes.

info_url: Option<String>

Optional URL to be embedded in the probe’s payload (e.g., an opt-out link).

probing_rate: u32

The target rate for sending probes, measured in packets per second (pps).

src: Address

Source address to use

sport: u16

Source port to use

dport: u16

Destination port to use

origin_id: u32

Origin ID associated with this outbound sender