pub fn outbound(
config: OutboundConfig,
outbound_rx: Receiver<InstructionType>,
socket: Arc<Socket>,
) -> JoinHandle<()>Expand description
Starts the outbound worker thread that awaits tasks and sends probes.
Arguments
config- configuration for the outbound worker threadoutbound_rx- on this channel we receive future tasks that are part of the current measurementsocket- the sender object to send probe/discovery/trace packets
Returns
The join handle of the outbound thread, used to await its completion at the end of a measurement